
# neuroglia: more than just brain glue

Neuroglia is a Python machine learning library for neurophysiology data.
It features scikit-learn compatible transformers for extracting features from extracellular electrophysiology & optical physiology data for machine learning pipelines.

[![CircleCI](https://circleci.com/gh/AllenInstitute/neuroglia.svg?style=shield&circle-token=d0a164bbf19524a24f0d6bc42535aab9c89f8c13)](https://circleci.com/gh/AllenInstitute/neuroglia)
[![Documentation Status](https://readthedocs.org/projects/neuroglia/badge/?version=latest)](http://neuroglia.readthedocs.io/en/latest/?badge=latest)

## Installation

`pip install git+https://github.com/AllenInstitute/neuroglia.git`

## Level of Support

We are planning on occasional updating this tool with no fixed schedule. Community involvement is encouraged through both issues and pull requests.

## License

[BSD-3-Clause](LICENSE)

## Authors

### Development Lead
- Justin Kiggins

### Contributors
- Nicholas Cain
- Michael Oliver
- Sahar Manavi
